from setuptools import setup, find_packages
setup(
name='parrotai',
version='0.1.7',
author='Andy Tran',
author_email='andy@joinparrot.ai',
description='API for Parrot AI - a decentralized AI.',
packages=['parrotai'],
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: Apache Software License',
'Operating System :: OS Independent',
],
python_requires='>=3.6',
)